@@ -2,6 +2,6 @@ import click
 import logging
 
 @click.group()
-def cli(debug):
+def cli():
     pass
     
